# Module 'eosclient'

This module configures an EOS client and supports SLC6 and above. The
module can optionally FUSE mount /eos and hook krb5 credentials to PAM.

Regarding EOS FUSE mounts, the module supports `eosxd` (aka FUSEX, used by default) and legacy `eosd`.
Which of the two is used for which instance is configured by the `eosclient::eosxd_ready` variable.

## Basic Usage:

To install the EOS client RPMs (and not configure any /eos mounts):

```puppet
include eosclient
```

## Configuring /eos mounts:

To configure and also enable /eos mounts, use yaml:

```YAML
---
eosclient::enable_fuse: true
```

To specify which EOS instances to mount, set the ``mounts`` to a list of
valid EOS instance names, e.g. ``['user','atlas']``. The default value
of the ``mounts`` param lets you specify this via a hiera array called
``eos_mounts``.

## Parameters to Eosclient Class
 * `enable_fuse` enable the /eos FUSE mounts. Defaults to `false`.
 * `enable_autofs` Mount /eos with autofs (instead of via a standalone `eosd` service).
   Defaults to `true`, required for `eosxd` mounts.
 * `mounts` array of EOS instances to mount. Defaults to
   `hiera(eos_mounts, [(a hardcoded list provided by the module)])`.
 * `yum_priority` priority of the eos yum repos. Defaults to `9`.
 * `manage_autofs_service` Whether or not this module should manage the
   puppet `Service['autofs']`. Set to `false` if the service is managed
   elsewhere (e.g by CVMFS). Defaults to `true`.
 * `manage_autofs_rpm` Whether or not to install the `autofs` package in
   this module. Set to `false` if the package is managed elsewhere, for
   example by the `autofs` module. Defaults to `true`.
 * `fuse_logrotate_days` Keep this many days of logs in
   `/var/log/eos/fuse/`. Defaults to `7`.
 * `version` which version to install. Defaults to `present`, the latest
   available version. It is not advised to use this option unless
   directed to by the EOS team.
## Deprecated parameters:
 * `enable_lemon` Boolean, no longer used - please do not set. Defaults to `false`
 * `enable_pam_hook` enable a PAM hook to link krb5 credentials to EOS at
   login time. Useful for AFS-like behaviour on interactive machines.
   Only needed for legacy `eosd` FUSE, defaults to `false`.

Puppet databindings allow all the above settings to be set via hiera:

```yaml
---
eosclient::enable_fuse: true
eosclient::enable_pam_hook: false
```

## /eos Configuration Options (FUSEX)
This module uses the default eosxd configution options, documented here:
https://gitlab.cern.ch/dss/eos/blob/master/fusex/README.md

If you would like to override a setting for *all* eosxd mounts on your
system, create a hiera hash called `eosclient::common_config`. For
example, custom cache options may be configured as follows:

```yaml
---
eosclient::common_config:
  conf:
    cache:
      size-mb: 1024
```

You are also able to override settings for just a subset of eos mounts with
the following syntax:

```yaml
---
eosclient::instance_config:
  home-a:
    conf:
      cache:
        size-mb: 1024
```

## Deprecations
Three hiera variables are deprecated but still work. Please migrate.
* `eos_mounts` becomes `eosclient::mounts`
* `eosclient_instance_config` becomes `eosclient::instance_config`.
* `eosclient_custom_config` becomes `eosclient::common_config`.
* `eosclient::eosxd_ready` should not be set - all EOS instances will by default be accessed via `eosxd`

Two hiera variables are deprecated and will cause a failiure if they are
set.
* `eosclient_common_config` becomes `eosclient::common_config`.
* `eosclient_eosxd_ready_instances` becomes `eosclient::eosxd_ready` (also deprecated, see above).


## Example: Auto-mounted /eos with defaults (like on LXPLUS)
This example shows how to setup the module with auto-mounted /eos, similar to
what is done on LXPLUS, and uses the default list of EOS mounts. This is the recommended configuration.

```puppet
include eosclient
```

```yaml
---
eosclient::enable_fuse: true
```

## Other examples

```puppet
include eosclient
```
To mount ONLY storage spaces for users whose username starts with letter _h_ :

```yaml
---
eosclient::enable_fuse: true
eosclient::mounts:
  - user
  - home-h
```

To mount ONLY a project space that starts with letter _c_ :

```yaml
---
eosclient::enable_fuse: true
eosclient::mounts:
  - project
  - project-c
```

## /eos Configuration Options (Legacy `eosd` FUSE)
This module provides sensible defaults for the /eos mounts. If you would
like to override a setting for *all* legacy FUSE eos mounts on your system, create a
hiera hash called `eosclient::common_config` and add your key/value
config pairs. For example, to disable the KRB5 feature, put this in
hiera:

```yaml
---
eosclient::common_config:
  EOS_FUSE_USER_KRB5CC: 0
```

You are also able to override settings for a subset of eos mounts with
the following syntax:

```yaml
---
eosclient::instance_config:
  user:
    EOS_FUSE_MGM_ALIAS: eosuser-web.cern.ch
  project:
    EOS_FUSE_MGM_ALIAS: eosuser-web.cern.ch
```
