class eosclient (
  Hash $instance_config,
  Hash $common_config,
  Array[String] $eosxd_ready     = [],
  String $version                = 'present',
  Boolean $enable_fuse           = false,
  Boolean $enable_pam_hook       = false,
  Boolean $enable_autofs         = true,
  Array[String] $mounts          = lookup('eos_mounts', Array[String], 'unique', []),
  Array[String] $default_mounts  = [],
  Integer $yum_priority          = 9,
  Boolean $manage_autofs_service = true,
  Boolean $manage_autofs_rpm     = true,
  Integer $fuse_logrotate_days   = 7,
  String  $fuse_logrotate_size   = '',
  Boolean $enable_lemon          = false,
  Hash $bindmounts               = {},
) {


  $_deprecated_eosclient_instance_config = lookup('eosclient_instance_config',Hash,'deep',{})
  $_deprecated_eosclient_custom_config   = lookup('eosclient_custom_config',Hash,'deep',{})

  if versioncmp($facts['os']['release']['major'], '6') < 0 or $facts['os']['architecture'] != 'x86_64' {
    fail ('eosclient supports only x86_64 and el6 or newer')
  }

  ensure_packages(['jemalloc', 'lsof'])

  # INC2475606: do not install debuginfo on desktops
  ensure_packages (['eos-client'], {
    'ensure'  => $version,
  })
  # the extra libraries in /opt are only on CC7 and newer, only need debuginfo here
  if versioncmp($facts['os']['release']['major'], '6') > 0 {
    ensure_packages (['eos-xrootd-debuginfo'], {
    })
  }
  if versioncmp($facts['os']['release']['major'], '7') == 0 {
    # this went away in Centos8
    ensure_packages (['eos-protobuf3-debuginfo'], {
    })
  }

  if $enable_fuse {
    include eosclient::fuse
  }

  if $enable_pam_hook {
    include eosclient::fuse::interactive
  }

  # RQF1360232
  Yumrepo <| |> -> Package <| provider != 'rpm' |>
  yumrepo { "eos${facts['os']['release']['major']}-desktop":
    descr    => "eos${facts['os']['release']['major']}-desktop",
    baseurl  => "http://linuxsoft.cern.ch/internal/repos/eos${facts['os']['release']['major']}-desktop/x86_64/os",
    gpgcheck => false,
    enabled  => 1,
    before   => Package['eos-client'],
  }
  yumrepo { "eos${facts['os']['release']['major']}-desktop-debuginfo":
    descr    => "eos${facts['os']['release']['major']}-desktop-debuginfo",
    baseurl  => "http://linuxsoft.cern.ch/internal/repos/eos${facts['os']['release']['major']}-desktop/x86_64/debug",
    gpgcheck => false,
    enabled  => 1,
    before   => Package['eos-client'],
  }

}
